@@ -7,15 +7,28 @@ const pkg = require('./package.json');
 const globals = id =>
   id.indexOf('@lumino/') === 0 ? id.replace('@lumino/', 'lumino_') : id;
 
+const external = id =>
+  (pkg.dependencies && !!pkg.dependencies[id]) ||
+  (pkg.peerDependencies && !!pkg.peerDependencies[id]);
+
+const plugins = [
+  nodeResolve({
+    preferBuiltins: true
+  }),
+  sourcemaps(),
+  postcss({
+    extensions: ['.css'],
+    minimize: true
+  })
+];
+
 export default [
   {
     input: 'lib/index',
-    external: id =>
-      (pkg.dependencies && !!pkg.dependencies[id]) ||
-      (pkg.peerDependencies && !!pkg.peerDependencies[id]),
+    external,
     output: [
       {
-        file: pkg.main,
+        file: pkg.browser,
         globals,
         format: 'umd',
         sourcemap: true,
@@ -28,15 +41,26 @@ export default [
         name: pkg.name
       }
     ],
-    plugins: [
-      nodeResolve({
-        preferBuiltins: true
-      }),
-      sourcemaps(),
-      postcss({
-        extensions: ['.css'],
-        minimize: true
-      })
-    ]
+    plugins
+  },
+  {
+    input: 'lib/index.node',
+    external,
+    output: [
+      {
+        file: pkg.main,
+        format: 'cjs',
+        sourcemap: true,
+        globals: globals,
+        name: pkg.name
+      },
+      {
+        file: pkg['module-node'] + '.js',
+        format: 'es',
+        sourcemap: true,
+        globals: globals
+      }
+    ],
+    plugins
   }
 ];
